==> oak-security-spi-1.9.4-sources.jar: org/apache/jackrabbit/oak/spi/security/principal/GroupPrincipalWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.spi.security.principal;

import java.security.Principal;
import java.security.acl.Group;
import java.util.Enumeration;

import javax.annotation.Nonnull;

import org.apache.jackrabbit.api.security.principal.GroupPrincipal;

@Deprecated
class GroupPrincipalWrapper extends PrincipalImpl implements GroupPrincipal {

    private final Group group;

    GroupPrincipalWrapper(@Nonnull Group group) {
        super(group.getName());
        this.group = group;
    }

    @Override
    public String getName() {
        return group.getName();
    }

    @Override
    public boolean isMember(Principal member) {
        return group.isMember(member);
    }

    @Override
    public Enumeration<? extends Principal> members() {
        return GroupPrincipals.transform(group.members());
    }
}

==> oak-security-spi-1.9.11-sources.jar: org/apache/jackrabbit/oak/spi/security/principal/GroupPrincipalWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.spi.security.principal;

import java.security.Principal;
import java.security.acl.Group;
import java.util.Enumeration;

import org.apache.jackrabbit.api.security.principal.GroupPrincipal;
import org.jetbrains.annotations.NotNull;

@Deprecated
class GroupPrincipalWrapper extends PrincipalImpl implements GroupPrincipal {

    private final Group group;

    GroupPrincipalWrapper(@NotNull Group group) {
        super(group.getName());
        this.group = group;
    }

    @Override
    public String getName() {
        return group.getName();
    }

    @Override
    public boolean isMember(Principal member) {
        return group.isMember(member);
    }

    @Override
    public Enumeration<? extends Principal> members() {
        return GroupPrincipals.transform(group.members());
    }
}
